@@ -67,11 +67,11 @@ class LambdaToEventbridge(
         :param id: - this is a a scope-unique id.
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
         :param event_bus_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the Event bus. Default: - EVENTBUS_NAME
-        :param event_bus_props: A new custom EventBus is created with provided props. Default: - None
-        :param existing_event_bus_interface: Existing instance of a custom EventBus. Default: - None
+        :param event_bus_props: Optional - user provided properties to override the default properties when creating a custom EventBus. Setting this value to ``{}`` will create a custom EventBus using all default properties. If neither this nor ``existingEventBusInterface`` is provided the construct will use the default EventBus. Providing both this and ``existingEventBusInterface`` causes an error. Default: - None
+        :param existing_event_bus_interface: Optional - user provided custom EventBus for this construct to use. Providing both this and ``eventBusProps`` causes an error. Default: - None
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
-        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` causes an error. Default: - Default properties are used.
         :param vpc_props: Properties to override default properties if deployVpc is true.
 
         :access: public
@@ -141,11 +141,11 @@ class LambdaToEventbridgeProps:
         '''
         :param deploy_vpc: Whether to deploy a new VPC. Default: - false
         :param event_bus_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the Event bus. Default: - EVENTBUS_NAME
-        :param event_bus_props: A new custom EventBus is created with provided props. Default: - None
-        :param existing_event_bus_interface: Existing instance of a custom EventBus. Default: - None
+        :param event_bus_props: Optional - user provided properties to override the default properties when creating a custom EventBus. Setting this value to ``{}`` will create a custom EventBus using all default properties. If neither this nor ``existingEventBusInterface`` is provided the construct will use the default EventBus. Providing both this and ``existingEventBusInterface`` causes an error. Default: - None
+        :param existing_event_bus_interface: Optional - user provided custom EventBus for this construct to use. Providing both this and ``eventBusProps`` causes an error. Default: - None
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
         :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
-        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` causes an error. Default: - Default properties are used.
         :param vpc_props: Properties to override default properties if deployVpc is true.
 
         :summary: The properties for the LambdaToEventbridge class.
@@ -206,7 +206,12 @@ class LambdaToEventbridgeProps:
     def event_bus_props(
         self,
     ) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.EventBusProps]:
-        '''A new custom EventBus is created with provided props.
+        '''Optional - user provided properties to override the default properties when creating a custom EventBus.
+
+        Setting
+        this value to ``{}`` will create a custom EventBus using all default properties. If neither this nor
+        ``existingEventBusInterface`` is provided the construct will use the default EventBus. Providing both this and
+        ``existingEventBusInterface`` causes an error.
 
         :default: - None
         '''
@@ -217,7 +222,10 @@ class LambdaToEventbridgeProps:
     def existing_event_bus_interface(
         self,
     ) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus]:
-        '''Existing instance of a custom EventBus.
+        '''Optional - user provided custom EventBus for this construct to use.
+
+        Providing both this and ``eventBusProps``
+        causes an error.
 
         :default: - None
         '''
@@ -245,7 +253,10 @@ class LambdaToEventbridgeProps:
     def lambda_function_props(
         self,
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
-        '''User provided props to override the default props for the Lambda function.
+        '''Optional - user provided props to override the default props for the Lambda function.
+
+        Providing both this and ``existingLambdaObj``
+        causes an error.
 
         :default: - Default properties are used.
         '''
